==> foundation-2.7.1.tgz: package/SocialZerply/SocialZerply.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialZerply = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M37.483 61.48c7.221.67 12.822 4.535 18.604 8.086 4.091 2.512 8.593 3.973 13.483 3.91 2.35-.029 4.435-.799 6.224-2.303.767-.646 1.085-.514 1.312.43 1.756 7.254-4.007 14.668-11.467 14.891-3.72.111-6.915-1.223-9.895-3.17-3.4-2.225-6.648-4.686-10.036-6.928-6.246-4.137-13.147-5.551-20.546-4.674-2.162.258-2.375.086-2.547-2.199-.321-4.287 1.237-7.81 4.117-10.93 8.217-8.893 16.293-17.912 23.846-27.389.647-.812 1.289-1.629 1.92-2.453.181-.238.557-.445.377-.795-.175-.34-.564-.185-.859-.17-3.609.201-7.217.402-10.834.322-1.868-.045-3.691-.299-5.413-1.059-2.893-1.271-3.835-3.455-2.733-6.391.896-2.383 2.238-4.523 3.709-6.594.416-.584.778-.727 1.449-.381 3.368 1.727 7.045 2.184 10.744 2.477 7.833.621 15.604.076 23.297-1.486 1.005-.203 1.029.293 1.118.982.456 3.51-.722 6.443-3.028 9.047-8.268 9.332-16.146 19.008-24.974 27.846-2.735 2.736-5.469 5.509-7.868 8.931z"
  }));
});
SocialZerply.displayName = 'SocialZerply';
export var SocialZerplyDimensions = {
  height: 100,
  width: 100
};

==> foundation-10.15.1.tgz: package/SocialZerply/SocialZerply.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export var SocialZerply = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(StyledIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M37.483 61.48c7.221.67 12.822 4.535 18.604 8.086 4.091 2.512 8.593 3.973 13.483 3.91 2.35-.029 4.435-.799 6.224-2.303.767-.646 1.085-.514 1.312.43 1.756 7.254-4.007 14.668-11.467 14.891-3.72.111-6.915-1.223-9.895-3.17-3.4-2.225-6.648-4.686-10.036-6.928-6.246-4.137-13.147-5.551-20.546-4.674-2.162.258-2.375.086-2.547-2.199-.321-4.287 1.237-7.81 4.117-10.93 8.217-8.893 16.293-17.912 23.846-27.389.647-.812 1.289-1.629 1.92-2.453.181-.238.557-.445.377-.795-.175-.34-.564-.185-.859-.17-3.609.201-7.217.402-10.834.322-1.868-.045-3.691-.299-5.413-1.059-2.893-1.271-3.835-3.455-2.733-6.391.896-2.383 2.238-4.523 3.709-6.594.416-.584.778-.727 1.449-.381 3.368 1.727 7.045 2.184 10.744 2.477 7.833.621 15.604.076 23.297-1.486 1.005-.203 1.029.293 1.118.982.456 3.51-.722 6.443-3.028 9.047-8.268 9.332-16.146 19.008-24.974 27.846-2.735 2.736-5.469 5.509-7.868 8.931z"
  }));
});
SocialZerply.displayName = 'SocialZerply';
export var SocialZerplyDimensions = {
  height: 100,
  width: 100
};
